#$Id: diag.sh,v 1.13 2005/09/07 17:54:36 rayg Exp $
# diagnostic shell aliases and commands for AERI-XP
# . diag.sh to include in shell commands


yymmdd() {
    TZ=GMT date '+%y%m%d'
}

YYMMDD=$(yymmdd)


#####################################
# Remote diagnostic routines
#

grab_to_from_() {
    HOST=$3
    FILE=$1
    DFILE=$2
    TPORT=1919 # tunnel port
    if [ -z "$FIREWALL" ]; then 
        scp aeri@$HOST:$FILE $DFILE
    else
        ssh -f -L$TPORT:$HOST:22 $FIREWALL sleep 5
        scp -P $TPORT aeri@localhost:$FILE $DFILE
    fi
}

# run command X on machine Y 
ssh_() { 
    HOST=$1
    if [ -z "$FIREWALL" ]; then 
        ssh -T aeri@$HOST
    else
        ssh -AT $FIREWALL ssh -T aeri@$HOST
    fi
}

ymdis_() {
    YMD=$1
    if [ -z "$YMD" ]; then
        YMD=$(yymmdd)
        echo "- using YYMMDD=$YMD -"
    fi
    export YMD
}    

echo getstats aeri-upgrade1 YYMMDD -- get stats as aeri-upgrade1-stats-YYMMDD.csv
getstats() {   
    ymdis_ $2
    export STATS=$1-stats-$YMD.csv
    grab_to_from_ /cygdrive/c/AE$YMD/cal/stats.csv $STATS $1
    ls -l $STATS
}

echo getqc aeri-upgrade1 YYMMDD -- get YYMMDD.QC file from FTP directory
getqc() { 
    ymdis_ $2
    export QC=$1-$YMD.QC
    grab_to_from_ /cygdrive/c/FTP/AE$YMD/$YMD.QC $QC $1
    ls -l $QC
}

echo getpar aeri-upgrade1 YYMMDD -- grab PAR file for a given day
getpar() {
    ymdis_ $2
    export PAR=$1-par-$YMD.PAR
    grab_to_from_ /cygdrive/c/FTP/AE$YMD/$YMD.PAR $PAR $1
    ls -l $PAR
}

echo getversion aeri-upgrade1 -- list AERI.VERSION file downloaded as aeri-upgrade1-AERI.VERSION
getversion() {
    grab_to_from_ /cygdrive/c/AERI_RUN/AERI.VERSION $1-AERI.VERSION $1
    less $1-AERI.VERSION
}

echo geterrors aeri-upgrade1 -- list aeri_error.log, all dates
geterrors() { 
ssh_ $1 <<EOF
cat /cygdrive/c/aeri_error.log
EOF
}

echo getreport aeri-upgrade1 YYMMDD -- get startups, errors, and warnings from ingest.log
getreport() {
ymdis_ $2
ssh_ $1 <<EOF
ls -al /cygdrive/c/ftp/outgoing
grep -a -E 'CRITICAL|ERROR|WARNING|STARTUP' /cygdrive/c/AE$YMD/cal/ingest.log
grep -a -E 'Exception' /cygdrive/c/AE$YMD/cal/mirror.out
echo CAL directory
/cygdrive/c/aeri_run/ohwhscan /cygdrive/c/AE$YMD/cal/*.{RLC,CXV,CVS,IMC,RES}
echo FTP directory
/cygdrive/c/aeri_run/ohwhscan /cygdrive/c/ftp/AE$YMD/*.{CXS,RNC,SUM}
EOF
}


# plot stats using matplotlib in python
# showstats stats-file.csv
echo showstats statsfile.csv -- use matplotlib in python to show ACQ96 run times
showstats() { 
python <<EOF
from matplotlib.pylab import *
d = file("$1",'r').readlines()[1:]
da = [ float(x.split(',')[2])*1000.0 for x in d]
plot(da)
ylabel('milliseconds')
xlabel('ACQ96 run index')
title("ACQ96 Execution Time for $1")
grid(True);
show()
EOF
}

export PS1='@: '


