# $Id: init.sh,v 1.12 2006/09/05 21:44:12 dennyh Exp $
#
# shell environment settings and routines for AERI-XP
# add to ~/.bashrc: ". /cygdrive/c/aeri_run/init.sh"
# 

AERI_RUN=/cygdrive/c/AERI_RUN

export PATH=$AERI_RUN:$PATH
export PYTHONPATH=$AERI_RUN

help() {
cat <<EOF
cdcal : change to cal directory for today
cdftp : change to ftp directory for today
cdsci : change to science work directory for today
sigs  : list current SIG files in science work directory
imirror: initialize mirror controller
hmirror: initialize mirror controller, rotate to home
sky/hbb/abb/cbb : rotate to preset positions according to mirror.beg
acq96check acq96.log : show unexpected parts (potential errors) in ACQ96.LOG
change_config_to DirectoryName : change AERI mode by change abcvals.num, mirror.beg and channel.map
EOF
}

python >$HOME/.aeri-vars.tmp <<EOF
import Config
#import re
#re_var = re.compile(r'[A-Z_][A-Z][A-Z_]+')
#print '\n'.join( ['export %s="%s"' % (a,b) for a,b in vars(Config).items() if re_var.match(a) and type(b)==type(str())])
all=['_WORK_DIR','YYMMDD']
print '\n'.join( ['export AE_%s="%s"' % (a,vars(Config)[a]) for a in all] )
print 'export AE_CAL_DIR="%s"' % Config.calDir(Config.YYMMDD)
print 'export AE_SCI_DIR="%s"' % Config.scienceWorkDir(Config.YYMMDD)
print 'export AE_FTP_DIR="%s"' % Config.outputDir(Config.YYMMDD)
EOF

. $HOME/.aeri-vars.tmp

aeri() {
python >$HOME/.aeri-vars.tmp <<EOF
import Config
import re
re_var = re.compile(r'[A-Z_][A-Z][A-Z_]+')
print '\n'.join( ['export %s="%s"' % (a,b) for a,b in vars(Config).items() if re_var.match(a) and type(b)==type(str())])
all=['_WORK_DIR','YYMMDD']
print '\n'.join( ['export AE_%s="%s"' % (a,vars(Config)[a]) for a in all] )
EOF

. $HOME/.aeri-vars.tmp
}


acq96check() {
FN=$1
if [ -z "$FN" ];then
  export FN=$AE_CAL_DIR\\\\acq96.log
  echo examining $FN
fi
python >/tmp/acq96.ok <<EOF
import re
# create a regex which matches the normal records complete
re_ordinary = re.compile(r'\w\d+;\d+/\d+/\d+;\d+:\d+:\d+\s+FORWARD_SCAN_DETECTOR_1 = \d+\s+REVERSE_SCAN_DETECTOR_1 = \d+\s+FORWARD_SCAN_DETECTOR_2 = \d+\s+REVERSE_SCAN_DETECTOR_2 = \d+\s*',re.MULTILINE)
# write the normal records to a temp file
print ''.join( re_ordinary.findall( file("$FN",'rt').read() ) )
EOF
# find the abnormal areas using diff
diff -u -b /tmp/acq96.ok $FN
}



status() { 
python <<EOF
import Sequencer
S = Sequencer.Sequencer()
print S.getCurrentSet()
EOF
}

cdcal() {
   cd $AE_CAL_DIR 
}

cdsci() {
   cd $AE_SCI_DIR
}

cdftp() {
   cd $AE_FTP_DIR
}

cdwork() {
   cd $AE__WORK_DIR
}

sigs() {
   here=$PWD
   cd $AE_SCI_DIR
   find . -name '*.SIG' -printf '%TH%TM%TS\t%f\t\t'
   cd $here
}

hresview() {
    /cygdrive/c/aeri_run/hresd/hresview $*
}

del_a_dir() {
    /cygdrive/c/aeri_run/Tidy.py del_a_dir
}

hmirror() {
    echo programming mirror..
    /cygdrive/c/aeri_run/Mirror.py program
    echo forcing to home position..
    /cygdrive/c/aeri_run/Mirror.py ready
}

imirror() {
    echo programming mirror..
    /cygdrive/c/aeri_run/Mirror.py program
    echo forcing to home position..
    /cygdrive/c/aeri_run/Mirror.py ready
}

hbb() {
    /cygdrive/c/aeri_run/Mirror.py rotate H
}

abb() {
    /cygdrive/c/aeri_run/Mirror.py rotate A
}

sky() {
    /cygdrive/c/aeri_run/Mirror.py rotate S
}

cbb() {
    /cygdrive/c/aeri_run/Mirror.py rotate C
}

viewer(){
    echo "Enter filename in windows(double back slash) format"
    read -p "File: " DMV_FILE
    JADA_CLASSPATH=".:jada.jar:lib/visad.jar:lib/dmv.jar:lib/log4j.jar:lib/xercesImpl.jar:lib/xml-apis.jar"
    cd $AERI_RUN/jada
    java -Djava.library.path=lib -cp `cygpath -p -w $JADA_CLASSPATH` edu.wisc.ssec.jada.DmvDataViewer $DMV_FILE
    cd -
}      

change_config_to() {
    FN=$1
    if [ -d "/cygdrive/c/config/setup/$FN" ]; then
      echo inserting $FN configuration..
      chmod u+w /cygdrive/c/config/abcvals.num
      chmod u+w /cygdrive/c/config/mirror.beg
      chmod u+w /cygdrive/c/config/channel.map
      cp /cygdrive/c/config/setup/$FN/* /cygdrive/c/config/.  
      Verify.py install fix
      DATE=`date`
      echo $FN config files installed: $DATE >> /cygdrive/c/aeri_config.log
      echo --------
      echo $FN CONFIGURATION INSTALLED CORRECTLY
      echo --------
    else
      echo Usage: change_config_to DirectoryName
      echo Please specify a valid setup directory
      echo 3body, 4body, ln2, op, RS_3
    fi
}

